
from setuptools import setup
setup(
    name='karaml',
    version='0.1.10',
    description='KARaML Tools wrapper package',
    long_description='Provides karaml_tools, a small package with the bare bones to get KARaML Tools running',
    url='https://bb-ai.net/KARaML/KARaML_Tools.html',
    author='brandonb',
    author_email='B.Bennett@leeds.ac.uk',
    packages=['karaml'],
    classifiers=['Development Status :: 1 - Planning'],
)
